<?php
/**
 * the class AudioproModuleClass
 */
class AudioproModuleClass extends FLBuilderModule {

    /** 
     * Constructor function for the module. You must pass the
     * name, description, dir and url in an array to the parent class.
     *
     * @method __construct
     */  
    public function __construct()
    {
      parent::__construct(array(
        'name'            => esc_html__( 'Audio PRO', 'beaver-audiopro' ),
        'description'     => esc_html__( 'An advanced HTML5 audio player', 'beaver-audiopro' ),
        'group'           => esc_html__( 'LambertGroup Modules', 'beaver-audiopro' ),
        'category'        => esc_html__( 'Audio', 'beaver-audiopro' ),
        'dir'             => audiopro_MODULES_DIR . 'modules/audiopro-module/',
        'url'             => audiopro_MODULES_URL . 'modules/audiopro-module/',
        'icon'            => 'format-audio.svg',
        'editor_export'   => true, // Defaults to true and can be omitted.
        'enabled'         => true, // Defaults to true and can be omitted.
        'partial_refresh' => true, // Defaults to false and can be omitted.
      ));


      /** 
       * Use these methods to enqueue css and js already
       * registered or to register and enqueue your own.
       */
      // Already registered
      $this->add_js('jquery');
      $this->add_js('jquery-ui-core');
      $this->add_js('jquery-ui-slider');
      $this->add_js('jquery-ui-progressbar');
      $this->add_js('jquery-effects-core');

      
      // Register and enqueue your own
      $this->add_css('audio2-html5-site-css', $this->url . 'audio2_html5/audio2_html5.css');

      $this->add_js('lbg-audio2-html5', $this->url . 'audio2_html5/js/audio2_html5.js', array(), '', true);
      $this->add_js('mousewheel', $this->url . 'audio2_html5/js/jquery.mousewheel.min.js', array(), '', true);
      $this->add_js('touchSwipe', $this->url . 'audio2_html5/js/jquery.touchSwipe.min.js', array(), '', true);

    }


}






/**
 * Register the module and its form settings.
 */
FLBuilder::register_module( 'AudioproModuleClass', array(


  'audiopro-tab-playersettings'      => array(
    'title'         => esc_html__( 'Player Settings', 'beaver-audiopro' ),
    'sections'      => array(

      'audiopro-section-generalsettings'  => array(
        'title'         => esc_html__( 'General Settings', 'beaver-audiopro' ),
        'fields'        => array(

          'skin' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Select Field', 'beaver-audiopro' ),
            'default'       => 'whiteControllers',
            'options'       => array(
              'whiteControllers'      => esc_html__( 'White Controllers', 'beaver-audiopro' ),
              'blackControllers'      => esc_html__( 'Black Controllers', 'beaver-audiopro' )
            )
          ),

          'width' => array(
            'type'         => 'unit',
            'label'        => esc_html__( 'Player Width', 'beaver-audiopro' ),
            'default'       => '500',
            'units'          => array( 'px' ),
            'default_unit' => 'px'
          ),

          'responsive' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Responsive', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'centerPlayer' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Center Player', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'loop' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Loop Playlist', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'autoPlay' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Auto Play', 'beaver-audiopro' ),
            'default'       => 'false',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'shuffle' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Shuffle', 'beaver-audiopro' ),
            'default'       => 'false',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'initialVolume' => array(
            'type'         => 'unit',
            'label'        => esc_html__( 'Initial Volume Value', 'beaver-audiopro' ),
            'default'       => '50',
            'units'          => array( '%' ),
            'default_unit' => '%',
            'slider' => array(
              'min'   => 0,
              'max'   => 100,
              'step'  => 1,
            )
          ),

          'artistImageWidth' => array(
            'type'         => 'unit',
            'label'        => esc_html__( 'Artist Image Width', 'beaver-audiopro' ),
            'default'       => '80',
            'units'          => array( 'px' ),
            'default_unit' => 'px',
            'slider' => array(
              'min'   => 40,
              'max'   => 120,
              'step'  => 5,
            )
          ),

          'artistImageHeight' => array(
            'type'         => 'unit',
            'label'        => esc_html__( 'Artist Image Height', 'beaver-audiopro' ),
            'default'       => '80',
            'units'          => array( 'px' ),
            'default_unit' => 'px',
            'slider' => array(
              'min'   => 40,
              'max'   => 120,
              'step'  => 5,
            )
          ),

          'fadeOutSoundAtTheEnd' => array(
            'type'         => 'unit',
            'label'        => esc_html__( 'Fade Out Sound (seconds)', 'beaver-audiopro' ),
            'default'       => '0',
            'units'          => array( 's' ),
            'default_unit' => 's',
            'slider' => array(
              'min'   => 0,
              'max'   => 60,
              'step'  => 1,
            ),
            'description'   => esc_html__( 'when the track has N seconds to finish the sound will start to fade out', 'beaver-audiopro' )
          ),

          'fadeInSoundAtTheBeginning' => array(
            'type'         => 'unit',
            'label'        => esc_html__( 'Fade In Sound (seconds)', 'beaver-audiopro' ),
            'default'       => '0',
            'units'          => array( 's' ),
            'default_unit' => 's',
            'slider' => array(
              'min'   => 0,
              'max'   => 60,
              'step'  => 1,
            ),
            'description'   => esc_html__( 'for the first N seconds of the track the sound will fade in', 'beaver-audiopro' )
          ),

          'globalStartPoint' => array(
            'type'          => 'text',
            'label'         => esc_html__( 'Optional General Audio Start Point', 'beaver-audiopro' ),
            'default'       => '',
            'maxlength'     => '8',
            'size'          => '10',
            'placeholder'   => esc_html__( 'HH:MM:SS', 'beaver-audiopro' ),
            'description'   => esc_html__( 'of this type: HH:MM:SS', 'beaver-audiopro' )
          ),

          'globalEndPoint' => array(
            'type'          => 'text',
            'label'         => esc_html__( 'Optional General Audio End Point', 'beaver-audiopro' ),
            'default'       => '',
            'maxlength'     => '8',
            'size'          => '10',
            'placeholder'   => esc_html__( 'HH:MM:SS', 'beaver-audiopro' ),
            'description'   => esc_html__( 'of this type: HH:MM:SS', 'beaver-audiopro' )
          ),

          'playerBg' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Player Background', 'beaver-audiopro' ),
            'default'       => '000000',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'bufferEmptyColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Empty Buffer Color', 'beaver-audiopro' ),
            'default'       => '929292',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'bufferFullColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Full Buffer Color', 'beaver-audiopro' ),
            'default'       => '454545',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'seekbarColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'SeekBar Color', 'beaver-audiopro' ),
            'default'       => 'FFFFFF',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'volumeOffColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Volume Off State Color', 'beaver-audiopro' ),
            'default'       => '454545',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'volumeOnColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Volume On State Color', 'beaver-audiopro' ),
            'default'       => 'FFFFFF',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'timerColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Timer Color', 'beaver-audiopro' ),
            'default'       => 'FFFFFF',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'songTitleColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Song Title - Text Color', 'beaver-audiopro' ),
            'default'       => 'a6a6a6',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'songAuthorColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Song Author - Text Color', 'beaver-audiopro' ),
            'default'       => 'FFFFFF',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'bordersDivColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Small buttons area (rewind, shuffle etc.) Borders Color', 'beaver-audiopro' ),
            'default'       => '333333',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'showRewindBut' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Show Rewind Button', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'showShuffleBut' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Show Shuffle Button', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'showDownloadBut' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Show Download Button', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'showBuyBut' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Show Buy Button', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'buyButTitle'     => array(
            'type'          => 'text',
            'default'       => 'Buy Now',
            'label'         => esc_html__( 'Buy Button Title', 'beaver-audiopro' )
          ),

          'buyButTarget' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Buy Button Target Window', 'beaver-audiopro' ),
            'default'       => '_blank',
            'options'       => array(
              '_blank'      => esc_html__( 'New Window', 'beaver-audiopro' ),
              '_self'      => esc_html__( 'Same Window', 'beaver-audiopro' )
            )
          ),

          'showLyricsBut' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Show Lyrics Button', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'lyricsButTitle'     => array(
            'type'          => 'text',
            'default'       => 'Lyrics',
            'label'         => esc_html__( 'Lyrics Button Title', 'beaver-audiopro' )
          ),

          'lyricsButTarget' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Buy Lyrics Target Window', 'beaver-audiopro' ),
            'default'       => '_blank',
            'options'       => array(
              '_blank'      => esc_html__( 'New Window', 'beaver-audiopro' ),
              '_self'      => esc_html__( 'Same Window', 'beaver-audiopro' )
            )
          ),

          'showTwitterBut' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Show Twitter Button', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'showAuthor' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Show Author', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'showTitle' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Show Title', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'showFacebookBut' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Show FaceBook Button', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'facebookAppID'     => array(
            'type'          => 'text',
            'default'       => '',
            'label'         => esc_html__( 'FaceBook AppID', 'beaver-audiopro' )
          ),

          'googleTrakingOn' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Activate Google Analytics Tracking', 'beaver-audiopro' ),
            'default'       => 'false',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'googleTrakingCode'     => array(
            'type'          => 'text',
            'default'       => '',
            'label'         => esc_html__( 'Your Google Analytics Tracking Code', 'beaver-audiopro' ),
            'description'   => esc_html__( 'Example of code: UA-3245693-1', 'beaver-audiopro' )
          ),

          'showSearchArea' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Show Search Area', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'searchAreaBg' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Search Area Background Color', 'beaver-audiopro' ),
            'default'       => '333333',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'searchInputText'     => array(
            'type'          => 'text',
            'default'       => 'search...',
            'label'         => esc_html__( 'Search Input Text', 'beaver-audiopro' )
          ),

          'searchInputBg' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Search Input Background Color', 'beaver-audiopro' ),
            'default'       => 'ffffff',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'searchInputBorderColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Search Input Border Color', 'beaver-audiopro' ),
            'default'       => '333333',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'searchInputTextColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Search Input Text Color', 'beaver-audiopro' ),
            'default'       => '333333',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'searchAuthor' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Search Inside Author Field', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'delay' => array(
            'type'         => 'unit',
            'label'        => esc_html__( 'Player Loading Delay (seconds)', 'beaver-audiopro' ),
            'default'       => '0.5',
            'units'          => array( 's' ),
            'default_unit' => 's',
            'slider' => array(
              'min'   => 0,
              'max'   => 5,
              'step'  => 0.5,
            )
          ),




        )
      ),

      'audiopro-section-playlistsettings'  => array(
        'title'         => esc_html__( 'Playlist Settings', 'beaver-audiopro' ),
        'fields'        => array(
          'showPlaylistOnInit' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Show Playlist On Init', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'showPlaylistBut' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Show Playlist Button', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'showPlaylist' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Show Playlist', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'playlistTopPos' => array(
            'type'         => 'unit',
            'label'        => esc_html__( 'Playlist Top Position', 'beaver-audiopro' ),
            'default'       => '2',
            'units'          => array( 'px' ),
            'default_unit' => 'px',
            'slider' => array(
              'min'   => 0,
              'max'   => 20,
              'step'  => 1,
            )
          ),

          'playlistBgColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Playlist Background Color', 'beaver-audiopro' ),
            'default'       => '000000',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'playlistRecordBgOffColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Playlist Record Background Off Color', 'beaver-audiopro' ),
            'default'       => '000000',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'playlistRecordBgOnColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Playlist Record Background On Color', 'beaver-audiopro' ),
            'default'       => '333333',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'playlistRecordBottomBorderOffColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Playlist Record Bottom Border Off Color', 'beaver-audiopro' ),
            'default'       => '333333',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'playlistRecordBottomBorderOnColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Playlist Record Bottom Border On Color', 'beaver-audiopro' ),
            'default'       => 'FFFFFF',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'playlistRecordTextOffColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Playlist Record Text Off Color', 'beaver-audiopro' ),
            'default'       => '777777',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'playlistRecordTextOnColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Playlist Record Text On Color', 'beaver-audiopro' ),
            'default'       => 'FFFFFF',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'numberOfThumbsPerScreen' => array(
            'type'         => 'unit',
            'label'        => esc_html__( 'Number Of Items Per Screen', 'beaver-audiopro' ),
            'default'       => '5',
            'slider' => array(
              'min'   => 1,
              'max'   => 30,
              'step'  => 1,
            )
          ),

          'playlistPadding' => array(
            'type'         => 'unit',
            'label'        => esc_html__( 'Playlist Padding', 'beaver-audiopro' ),
            'default'       => '18',
            'units'          => array( 'px' ),
            'default_unit' => 'px',
            'slider' => array(
              'min'   => 0,
              'max'   => 40,
              'step'  => 1,
            )
          ),

          'showPlaylistNumber' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Show Playlist Number', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'showAuthorNameInPlaylist' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Show Author Name In The Playlist', 'beaver-audiopro' ),
            'default'       => 'false',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),





        )
      ),

      
      'audiopro-section-categoriessettings'  => array(
        'title'         => esc_html__( 'Categories Settings', 'beaver-audiopro' ),
        'fields'        => array(

          'showCategories' => array(
            'type'          => 'select',
            'label'         => esc_html__( 'Show Categories', 'beaver-audiopro' ),
            'default'       => 'true',
            'options'       => array(
              'true'      => esc_html__( 'Yes', 'beaver-audiopro' ),
              'false'      => esc_html__( 'No', 'beaver-audiopro' )
            )
          ),

          'categoryRecordBgOffColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Category Record Background Off Color', 'beaver-audiopro' ),
            'default'       => '191919',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'categoryRecordBgOnColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Category Record Background On Color', 'beaver-audiopro' ),
            'default'       => '252525',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'categoryRecordBottomBorderOffColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Category Record Bottom Border Off Color', 'beaver-audiopro' ),
            'default'       => '2f2f2f',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'categoryRecordBottomBorderOnColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Category Record Bottom Border On Color', 'beaver-audiopro' ),
            'default'       => '2f2f2f',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'categoryRecordTextOffColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Category Record Text Off Color', 'beaver-audiopro' ),
            'default'       => '4c4c4c',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'categoryRecordTextOnColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Category Record Text On Color', 'beaver-audiopro' ),
            'default'       => '00b4f9',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'firstCateg'     => array(
            'type'          => 'text',
            'default'       => '',
            'label'         => esc_html__( 'First Selected Category', 'beaver-audiopro' ),
            'description'   => esc_html__( 'it must be one of the defined categories or you can leave it blank', 'beaver-audiopro' )
          ),

          'selectedCategBg' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Selected Categ Background Color', 'beaver-audiopro' ),
            'default'       => '333333',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'selectedCategOffColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Selected Categ Off Color', 'beaver-audiopro' ),
            'default'       => 'FFFFFF',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'selectedCategOnColor' => array(
            'type'          => 'color',
            'label'         => esc_html__( 'Selected Categ On Color', 'beaver-audiopro' ),
            'default'       => '00b4f9',
            'show_reset'    => true,
            'show_alpha'    => true
          ),

          'selectedCategMarginBottom' => array(
            'type'         => 'unit',
            'label'        => esc_html__( 'Selected Category Bottom Margin', 'beaver-audiopro' ),
            'default'       => '12',
            'units'          => array( 'px' ),
            'default_unit' => 'px',
            'slider' => array(
              'min'   => 0,
              'max'   => 40,
              'step'  => 1,
            )
          ),



        )
      )
      

    )
  ),

        
  'audiopro-tab-playlist'      => array( // Tab
    'title'         => esc_html__( 'Playlist', 'beaver-audiopro' ),
    'sections'      => array( // Tab Sections

      'audiopro-section-playlistitems'  => array(
        'title'         => '',// Section Title
        'fields'        => array(

          'playlist_item_form' => array(
            'type'          => 'form',
            'label'         => esc_html__('Playlist Item', 'fl-builder'),
            'form'          => 'playlist_item_form', // ID of a registered form.
            'preview_text' => 'titlex', // ID of a field to use for the preview text.
            'multiple'     => true,
          )


        )
      )
    )
  )



) );





/**
 * Register a settings form to use in the "form" field type above  --   For the playlist
 */
FLBuilder::register_settings_form('playlist_item_form', array(
  'title' => esc_html__('Playlist Item', 'beaver-audiopro'),
  'tabs'  => array(
    'audiopro-generic-tab'      => array( // Tab
        'title'         => esc_html__('General', 'beaver-audiopro'), // Tab title
        'sections'      => array( // Tab Sections
            'audiopro-generic-section'       => array( // Section
                'title'         => '', // Section Title
                'fields'        => array( // Section Fields
                    
                    'titlex'       => array(
                        'type'          => 'text',
                        'label'         => esc_html__('Title', 'beaver-audiopro'),
                        'default'       => '',
                        'placeholder'   => esc_html__( 'the song title', 'beaver-audiopro' ),
                    ),

                    'author'       => array(
                      'type'          => 'text',
                      'label'         => esc_html__('Author', 'beaver-audiopro'),
                      'default'       => '',
                      'placeholder'   => esc_html__( 'the song author', 'beaver-audiopro' ),
                    ),

                    'category'       => array(
                      'type'          => 'text',
                      'label'         => esc_html__('Category', 'beaver-audiopro'),
                      'default'       => '',
                      'description'   => esc_html__( 'If you will define multiple categories for each song, you will separate them by a semicolon. Example: Category 1; Category 2', 'beaver-audiopro' ),
                    ),

                    'imgplaylist' => array(
                      'type'          => 'photo',
                      'label'         => esc_html__('Playlist Image', 'beaver-audiopro'),
                      'show_remove'   => true,
                    ),

                    'mp3' => array(
                      'type'          => 'audiopro-upload-audio',
                      'label'         => esc_html__('MP3 file (Chrome, IE, Safari)', 'beaver-audiopro'),
                      'show_remove'   => true,
                    ),

                    'ogg' => array(
                      'type'          => 'audiopro-upload-audio',
                      'label'         => esc_html__('Optional OGG file (Older versions of Mozilla, Opera)', 'beaver-audiopro'),
                      'show_remove'   => true,
                    ),

                    'buylink' => array(
                      'type'          => 'link',
                      'label'         => esc_html__('Buy Link', 'beaver-audiopro'),
                      'show_target'   => false,
                      'show_nofollow' => false,
                    ),

                    'lyricslink' => array(
                      'type'          => 'link',
                      'label'         => esc_html__('Lyrics Link', 'beaver-audiopro'),
                      'show_target'   => false,
                      'show_nofollow' => false,
                    ),

                    'startpoint' => array(
                      'type'          => 'text',
                      'label'         => esc_html__( 'Optional Audio Start Point', 'beaver-audiopro' ),
                      'default'       => '',
                      'maxlength'     => '8',
                      'size'          => '10',
                      'placeholder'   => esc_html__( 'HH:MM:SS', 'beaver-audiopro' ),
                      'description'   => esc_html__( 'of this type: HH:MM:SS', 'beaver-audiopro' )
                    ),
          
                    'endpoint' => array(
                      'type'          => 'text',
                      'label'         => esc_html__( 'Optional Audio End Point', 'beaver-audiopro' ),
                      'default'       => '',
                      'maxlength'     => '8',
                      'size'          => '10',
                      'placeholder'   => esc_html__( 'HH:MM:SS', 'beaver-audiopro' ),
                      'description'   => esc_html__( 'of this type: HH:MM:SS', 'beaver-audiopro' )
                    ),

                )
            )
        )
    ),
  )
));
?>
